@@ -52,12 +52,14 @@ Type::Type(TypeType tot)
 	attrs_ = new AttrList();
 	attr_byteorder_expr_ = 0;
 	attr_checks_ = new ExprList();
+	attr_enforces_ = new ExprList();
 	attr_chunked_ = false;
 	attr_exportsourcedata_ = false;
 	attr_if_expr_ = 0;
 	attr_length_expr_ = 0;
 	attr_letfields_ = 0;
 	attr_multiline_end_ = 0;
+	attr_linebreaker_ = 0;
 	attr_oneline_ = false;
 	attr_refcount_ = false;
 	attr_requires_ = new ExprList();
@@ -80,6 +82,7 @@ Type::~Type()
 	delete attr_if_expr_;
 	delete attr_length_expr_;
 	delete_list(ExprList, attr_checks_);
+	delete_list(ExprList, attr_enforces_);
 	delete_list(ExprList, attr_requires_);
 	}
 
@@ -158,6 +161,10 @@ void Type::ProcessAttr(Attr* a)
 			attr_checks_->push_back(a->expr());
 			break;
 
+		case ATTR_ENFORCE:
+			attr_enforces_->push_back(a->expr());
+			break;
+
 		case ATTR_EXPORTSOURCEDATA:
 			attr_exportsourcedata_ = true;
 			break;
@@ -187,7 +194,9 @@ void Type::ProcessAttr(Attr* a)
 			break;
 
 		case ATTR_LINEBREAKER:
-			ASSERT(0);
+			if (strlen(a->expr()->orig()) != 6 )
+				throw Exception(this, "invalid line breaker length, must be a single ASCII character. (Ex: \"\\001\".)");
+			attr_linebreaker_ = a->expr();
 			break;
 
 		case ATTR_MULTILINE:
@@ -274,7 +283,7 @@ void Type::Prepare(Env* env, int flags)
 	if ( attr_if_expr() )
 		{
 		ASSERT(value_var());
-		ID *has_value_id = new ID(fmt("has_%s", value_var()->Name()));
+		ID *has_value_id = new ID(strfmt("has_%s", value_var()->Name()));
 		has_value_field_ = new LetField(has_value_id, 
 			extern_type_bool->Clone(),
 			attr_if_expr());
@@ -285,7 +294,7 @@ void Type::Prepare(Env* env, int flags)
 		{
 		ASSERT(flags & TO_BE_PARSED);
 		ID *parsing_complete_var = 
-			new ID(fmt("%s_parsing_complete", 
+			new ID(strfmt("%s_parsing_complete", 
 				value_var() ? value_var()->Name() : "val"));
 		DEBUG_MSG("Adding parsing complete var: %s\n",
 			parsing_complete_var->Name());
@@ -446,6 +455,13 @@ void Type::GenBufferConfiguration(Output *out_cc, Env *env)
 			out_cc->inc_indent();
 			out_cc->println("{");
 
+			if ( BufferableWithLineBreaker() )
+				out_cc->println("%s->SetLineBreaker((u_char*)%s);", 
+				    env->LValue(flow_buffer_id), LineBreaker()->orig());
+			else 
+				out_cc->println("%s->UnsetLineBreaker();", 
+				    env->LValue(flow_buffer_id));
+
 			out_cc->println("%s->NewLine();",
 				env->LValue(flow_buffer_id));
 
@@ -776,6 +792,20 @@ void Type::GenParseCode3(Output* out_cc, Env* env, const DataPtr& data, int flag
 
 	if ( size_var() )
 		ASSERT(env->Evaluated(size_var()));
+
+	foreach(i, ExprList, attr_enforces_)
+		{
+		Expr* enforce = *i;
+		const char* enforce_expr = enforce->EvalExpr(out_cc, env);
+		out_cc->println("// Evaluate '&enforce' attribute");
+		out_cc->println("if (!%s)", enforce_expr);
+		out_cc->inc_indent();
+		out_cc->println("{");
+		out_cc->println("throw binpac::ExceptionEnforceViolation(\"%s\");", data_id_str_.c_str());
+		out_cc->println("}");
+		out_cc->dec_indent();
+		}
+
 	}
 
 Type *Type::MemberDataType(const ID *member_id) const
@@ -809,7 +839,7 @@ bool Type::AddSizeVar(Output* out_cc, Env* env)
 
 	ASSERT(! incremental_input());
 
-	ID *size_var_id = new ID(fmt("%s__size", 
+	ID *size_var_id = new ID(strfmt("%s__size", 
 		value_var() ? value_var()->Name() : decl_id()->Name()));
 
 	DEBUG_MSG("adding size var `%s' to env %p\n", size_var_id->Name(), env);
@@ -999,6 +1029,17 @@ bool Type::Bufferable() const
 	return IsEmptyType() || BufferableByLength() || BufferableByLine();
 	}
 
+bool Type::BufferableWithLineBreaker() const
+	{
+	// If the input is an ASCII line with a given linebreaker;
+	return attr_linebreaker_ != 0;
+	}
+
+Expr* Type::LineBreaker() const
+	{
+	return attr_linebreaker_;
+	}
+
 Type::BufferMode Type::buffer_mode() const
 	{
 	if ( IsEmptyType() )
